.. _swh-core:

Software Heritage - Core foundations
====================================

Low-level utilities and helpers used by almost all other modules in the stack.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   cli
   /apidoc/swh.core
